Built-in DataProcessor
========================================================

Formatters
-----------------------------

.. toctree::
    :maxdepth: 1

    Datetime Formatter <datetime>
    Int Formatter <int>


Transformers
-----------------------------


.. toctree::
    :maxdepth: 1

    Discrete Transformer <discrete>
    Column Order Transformer  <column_order>
    Nan Transformer <nan>
    Numeric Transformer <numeric>



Generators
-----------------------------

.. toctree::
    :maxdepth: 1

    Email Generator <email>
